@@ -8,6 +8,9 @@ DATA_NAME = 'data'
 JSON_PATH = INPUT_DATA_DIR / (DATA_NAME + '.json')
 YAML_PATH = INPUT_DATA_DIR / (DATA_NAME + '.yaml')
 TOML_PATH = INPUT_DATA_DIR / (DATA_NAME + '.toml')
+NON_EXISTENT_NAME = 'woo'
+NON_EXISTENT_IN_PATH = INPUT_DATA_DIR / NON_EXISTENT_NAME
+NON_EXISTENT_INPUT_JSON_PATH = INPUT_DATA_DIR / (NON_EXISTENT_NAME + '.json')
 CUSTOM_CONFIG_IN_PATH = INPUT_DATA_DIR / DATA_NAME
 ENV_PATH = GENERATED_DATA_DIR / '.env'
 CUSTOM_CONFIG_OUT_PATH = GENERATED_DATA_DIR / 'config'
